UserAction class

Constructors

UserAction()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getUsername([dynamic callback]) → Future
isLoggedIn([dynamic callback]) → Future
login(String username) → Future
logout([dynamic callback]) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttribute(String key, String value, [dynamic callback]) → Future
setProfile(dynamic profile, [dynamic callback]) → Future
setTag(String tag, [dynamic callback]) → Future
setTags(List<String> tag, [dynamic callback]) → Future
toString() → String
A string representation of this object.
inherited
unsetAttribute(String key, [dynamic callback]) → Future
unsetTag(String tag, [dynamic callback]) → Future
unsetTags(List<String> tag, [dynamic callback]) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

shared → UserAction
no setter